package com.playlet.system.mapper;

import java.util.List;
import com.playlet.system.domain.PlayletUserExpandAccount;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 用户外部账号Mapper接口
 *
 * @author ruoyi
 * @date 2024-04-14
 */
public interface PlayletUserExpandAccountMapper extends BaseMapper<PlayletUserExpandAccount>
{
    /**
     * 查询用户外部账号
     *
     * @param id 用户外部账号主键
     * @return 用户外部账号
     */
    public PlayletUserExpandAccount selectPlayletUserExpandAccountById(Long id);

    /**
     * 查询用户外部账号列表
     *
     * @param playletUserExpandAccount 用户外部账号
     * @return 用户外部账号集合
     */
    public List<PlayletUserExpandAccount> selectPlayletUserExpandAccountList(PlayletUserExpandAccount playletUserExpandAccount);

    /**
     * 新增用户外部账号
     *
     * @param playletUserExpandAccount 用户外部账号
     * @return 结果
     */
    public int insertPlayletUserExpandAccount(PlayletUserExpandAccount playletUserExpandAccount);

    /**
     * 修改用户外部账号
     *
     * @param playletUserExpandAccount 用户外部账号
     * @return 结果
     */
    public int updatePlayletUserExpandAccount(PlayletUserExpandAccount playletUserExpandAccount);

    /**
     * 删除用户外部账号
     *
     * @param id 用户外部账号主键
     * @return 结果
     */
    public int deletePlayletUserExpandAccountById(Long id);

    /**
     * 批量删除用户外部账号
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePlayletUserExpandAccountByIds(String[] ids);
}
